import { EmbedBuilder, ButtonBuilder, ActionRowBuilder } from 'discord.js';
import { ExtendedInteraction, ExtendedMessage, CustomizableButton } from './typedef';
/**
 * **Documentation Url** of the type: https://simplyd.js.org/docs/general/buttonPages#pagebuttons
 */
export interface Pagebuttons {
    first?: CustomizableButton;
    next?: CustomizableButton;
    back?: CustomizableButton;
    last?: CustomizableButton;
    delete?: CustomizableButton;
}
/**
 * **Documentation Url** of the options: https://simplyd.js.org/docs/general/buttonPages#pagesoptions
 */
export declare type pagesOptions = {
    buttons?: Pagebuttons;
    skips?: boolean;
    delete?: boolean;
    dynamic?: boolean;
    count?: boolean;
    rows?: ActionRowBuilder<ButtonBuilder>[];
    embeds?: EmbedBuilder[];
    timeout?: number;
    disable?: 'Label' | 'Emoji' | 'None';
    strict?: boolean;
};
/**
 * ## buttonPages
 * ### An *powerful yet customizable* **Embed Paginator**
 *
 * @async
 * @param {ExtendedMessage|ExtendedInteraction} msgOrint [`ExtendedMessage`](https://simplyd.js.org/docs/typedef/extendedmessage) | [`ExtendedInteraction`](https://simplyd.js.org/docs/typedef/extendedinteraction)
 * @param {pagesOptions} options [`pagesOptions`](https://simplyd.js.org/docs/general/buttonpages#pagesoptions)
 * @returns {Promise<void>} `void`
 *
 * ---
 *
 * @link [`Documentation`](https://simplyd.js.org/docs/general/buttonPages)
 * @example simplydjs.buttonPages(interaction, [embed1, embed2] )
 */
export declare function buttonPages(msgOrint: ExtendedMessage | ExtendedInteraction, options?: pagesOptions): Promise<void>;
